
# Yoast SEO Site Studio Integration

The **Yoast SEO Site Studio Integration** module extracts readable text content from Acquia Site Studio components and makes it available for **Yoast SEO meta descriptions** — both in the UI preview and Metatag token (`[node:sitestudiocontents]`).

---

## 🚀 Features

- Automatically populates Yoast SEO meta descriptions using Site Studio content.
- Provides a custom token: `[node:sitestudiocontents]` for use in Metatag settings.
- Integrates with the Yoast SEO snippet editor in real time via JavaScript.
- Extracts multiple component types: `text`, `string`, and HTML markup from JSON.
- Truncates frontend meta description to 160 characters.

---

## 🧩 Requirements

- Drupal ^9 || ^10 || ^11
- [Yoast SEO](https://www.drupal.org/project/yoast_seo)  
- [Acquia Cohesion / Site Studio](https://www.drupal.org/project/cohesion)

---

## ⚙️ Installation

1. Place the module in your `/modules/custom` directory.
2. Enable the module via UI or Drush:

    ```bash
    drush en yoastseo_sitestudio_integration -y
    ```

_Optional: You may use `composer require drupal/yoastseo_sitestudio_integration` if it becomes available on Drupal.org._

---

## 🛠️ Configuration

### Add `[node:sitestudiocontents]` Token in Metatag

1. Go to:  
   **Configuration** → **Search and metadata** → **Metatag**.
2. Choose a metatag config (e.g., "Default" or "Article").
3. In the **Description** field, enter:

    ```
    [node:sitestudiocontents]
    ```

4. Save the configuration.

This will auto-fill the meta description using extracted Site Studio content.

---

## 📸 Screenshots

### Shows the Meta Tag configuration with custom tokens including [node:sitestudiocontents]

![Yoast Meta Auto-Fill](screenshots/meta-tags-token-settings.png)

### Displays the Site Studio Layout Canvas with components: Single text WYSIWYG and Text

![Metatag Token Setup](screenshots/sitestudio-layout-canvas-components.png)

### Shows the rendered HTML <title> and <meta name="description"> tags on the frontend.

![Metatag Token Setup](screenshots/html-page-title-description-output.png)

### Shows editing of the "Single text WYSIWYG" component in Site Studio, with text “Yoast module”.

![Metatag Token Setup](screenshots/sitestudio-single-text-editor.png)
---

## 📁 Project Structure

```
yoastseo_sitestudio_integration/
├── js/
│   └── yoastseo_sitestudio_integration.js       # Real-time JS integration
├── yoastseo_sitestudio_integration.module       # Hooks and token logic
├── yoastseo_sitestudio_integration.info.yml
├── yoastseo_sitestudio_integration.libraries.yml
```

---

## 🔍 Developer Notes

- Reads JSON from `field_layout_canvas → modelAsJson`.
- Uses a generic selector:  
  `[id^="field_layout_canvas_"][id$="_modelAsJson"]` for JS flexibility.
- Extracts `.text` keys recursively for real-time and backend usage.
- Description `<meta>` tag is limited to 160 characters via `hook_page_attachments_alter()`.

---

## 👤 Maintainers

- **Immaculate Xavier**  
  Technical Lead – Drupal  
  [https://www.drupal.org/u/immaculatexavier](https://www.drupal.org/u/immaculatexavier)

---

## 📄 License

Licensed under the [GNU General Public License v2.0 or later](https://www.gnu.org/licenses/gpl-2.0.html).
