(function (Drupal, drupalSettings) {
  Drupal.behaviors.YoastseoSitestudioIntegration = {
    attach: function () {
      function extractTextFromComponents(jsonValues) {
        try {
          var components = JSON.parse(jsonValues);
          var textContents = [];

          if (components && components.model) {
            Object.values(components.model).forEach(function (component) {
              Object.entries(component).forEach(function ([key, value]) {
                if (typeof value === 'string' && value.trim()) {
                  textContents.push(value);
                } else if (value && typeof value === 'object' && value.text) {
                  textContents.push(value.text);
                }
              });
            });
          }

          var fullText = textContents.join(' ');
          return fullText;
        } catch (error) {
          return '';
        }
      }

      function stripHtmlTags(html) {
        var tmp = document.createElement('DIV');
        tmp.innerHTML = html;
        tmp.querySelectorAll('script, style').forEach(el => el.remove());
        return tmp.textContent || tmp.innerText || '';
      }

      function getCanvasElement() {
        return document.querySelector('[id^="field_layout_canvas_"][id$="_modelAsJson"]');
      }

      function updateYoastMetaDescription() {
        var snippetEditor = document.querySelector('.js-snippet-editor-meta-description');
        var canvasElement = getCanvasElement();

        if (snippetEditor && canvasElement) {
          var siteStudioContent = extractTextFromComponents(canvasElement.value);
          var cleanText = stripHtmlTags(siteStudioContent).trim();

          snippetEditor.value = cleanText;

          if (typeof YoastSEO !== 'undefined' && typeof YoastSEO.app !== 'undefined') {
            YoastSEO.app.rawData.sitestudiocontents = cleanText;
            YoastSEO.app.refresh();
          }
        } else {
          if (!canvasElement) { console.error('Site Studio canvas field not found');
          }
          if (!snippetEditor) { console.error('Yoast meta description field not found');
          }
        }
      }

      document.addEventListener('DOMContentLoaded', updateYoastMetaDescription);
    }
  };
})(Drupal, drupalSettings);
